import Head from "next/head";
import { useRouter } from "next/router";
import React, { ReactElement } from "react";

export type MetaProps = {
  title?: string;
  description?: string;
  image?: string;
  date?: string;
};

const defaultMeta: MetaProps = {
  title: "Willie&apos;s Space",
  description: "Willie&apos;s Space",
};

const Meta = (metaProps: MetaProps): ReactElement => {
  const baseUrl = `https://www.wll.moe`;
  const router = useRouter();
  const meta = {
    ...defaultMeta,
    ...metaProps,
  };
  return (
    <Head>
      <title>{meta.title}</title>
      <meta name="robots" content="follow, index" />
      <meta name="description" content={meta.description} />
      <meta property="og:url" content={`${baseUrl}${router.asPath}`} />
      <link rel="canonical" href={`${baseUrl}${router.asPath}`} />
      <meta property="og:site_name" content={meta.title} />
      <meta property="og:description" content={meta.description} />
      <meta property="og:title" content={meta.title} />
      {meta.date && (
        <meta property="article:published_time" content={meta.date} />
      )}
    </Head>
  );
};

export default Meta;
